<?php

/**
 * Plugin Name: Test Plugin
 * Description: Test
 * Version: 1.0.4
 * Author: Poly Plugins
 * Author URI: https://www.polyplugins.com
 * Plugin URI: https://www.polyplugins.com
 */

namespace Company;

use PolyPlugins\Settings;

if (!defined('ABSPATH')) exit;

class Test_Plugin
{
  /**
	 * Full path and filename of plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin    Full path and filename of plugin.
	 */
  private $plugin;
  
  /**
	 * Namespace of plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin    Full path and filename of plugin.
	 */
  private $namespace;

  /**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_slug    The ID of this plugin.
	 */
  private $plugin_slug;

  /**
	 * The plugin name
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    Name of the plugin
	 */
  private $plugin_name;

  /**
	 * The settings class configuration
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      array    $config    The settings class configuration
	 */
  private $config;

  /**
	 * The plugin's options fields
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      array    $fields    The plugin's options fields
	 */
  private $fields;

  /**
	 * The Settings class
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      object    $settings    The Settings class
	 */
  private $settings;

  /**
	 * Store admin notices
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      array    $admin_notice    Store admin notices
	 */
  private $admin_notice;
  
  /**
   * __construct
   *
   * @return void
   */
  public function __construct()
  {
    $this->plugin      = __FILE__;
    $this->namespace   = __NAMESPACE__;
    $this->plugin_slug = dirname(plugin_basename($this->plugin));
    $this->plugin_name = __(mb_convert_case(str_replace('-', ' ', $this->plugin_slug), MB_CASE_TITLE), $this->plugin_slug);
    
    $this->config  = array(
      'page'       => 'options-general.php', // You can use non php pages such as woocommerce here to display a submenu under Woocommerce
      'position'   => 1, // Lower number moves the link position up in the submenu
      'capability' => 'manage_options', // What permission is required to see and edit settings
      'logo'       => '/img/logo.png', // Your custom logo. Comment out this line to use the Reusable Admin Panel logo
      'css'        => '/css/style.css', // Your custom colors and styles. Comment out to use default style.
      'js'         => '/js/admin.js', // Your custom javascript. Comment out to use default js.
      'support'    => 'https://www.polyplugins.com/support/', // Your support link. Comment out to have no support link.
    );

    $this->fields = array(
      'general' => array(
        array(
          'name'     => __('Enabled', $this->plugin_slug),
          'type'     => 'switch',
          'default'  => false,
        ),
        array(
          'name'     => __('Environment', $this->plugin_slug),
          'type'     => 'dropdown_toggle',
          'options'  => array(
            'Production' => array(
              array(
                'name'     => __('Production URL', $this->plugin_slug),
                'type'     => 'url',
                'help'     => __('Enter your base url for your production installation.', $this->plugin_slug),
              ),
              array(
                'name'     => __('Production Token', $this->plugin_slug),
                'type'     => 'password',
                'help'     => __('Enter production token', $this->plugin_slug),
              ),
            ),
            'Development' => array(
              array(
                'name'     => __('Development URL', $this->plugin_slug),
                'type'     => 'url',
                'help'     => __('Enter your base url for your development installation.', $this->plugin_slug),
              ),
              array(
                'name'     => __('Development Token', $this->plugin_slug),
                'type'     => 'password',
                'help'     => __('Enter development token', $this->plugin_slug),
              ),
            )
          ),
          'help'     => __('Select an option from the dropdown.', $this->plugin_slug),
        ),
        array(
          'name'      => __('Button', $this->plugin_slug),
          'type'      => 'button',
          'data'      => array(
            array(
              'title' => 'Action 1', // general-action-1 would be the id you'd target in js
              'class' => 'primary',
              ),
            array(
              'title'  => 'Action 2',
              'class'  => 'secondary',
              'url'    => 'https://www.polyplugins.com', // If no url then javascript:void(0) is used, this is useful for custom js
              'target' => '_blank',
            )
          )
        ),
        array(
          'name'     => __('Username', $this->plugin_slug),
          'type'     => 'text',
          'default'  => false,
          'help'     => __('Enter a username.', $this->plugin_slug),
        ),
        array(
          'name'     => __('URL', $this->plugin_slug),
          'type'     => 'url',
          'default'  => false,
          'help'     => __('Enter a URL. Ex: https://www.example.com', $this->plugin_slug),
        ),
        array(
          'name'     => __('Password', $this->plugin_slug),
          'type'     => 'password',
          'default'  => 'test',
          'help'     => __('Enter a password. Note: This is stored in the DB as plain text as most other plugins do, we will change this if requested.', $this->plugin_slug),
        ),
        array(
          'name'     => __('Number', $this->plugin_slug),
          'type'     => 'number',
          'default'  => false,
          'help'     => __('Enter a number.', $this->plugin_slug),
          'required' => true,
        ),
        array(
          'name'     => __('Time', $this->plugin_slug),
          'type'     => 'time',
          'default'  => false,
          'help'     => __('Select a time.', $this->plugin_slug),
        ),
        array(
          'name'     => __('Date', $this->plugin_slug),
          'type'     => 'date',
          'default'  => false,
          'help'     => __('Select a date.', $this->plugin_slug),
        ),
        array(
          'name'     => __('Color Picker', $this->plugin_slug),
          'type'     => 'color',
          'default'  => '#00ff00',
          'help'     => __('Select a color.', $this->plugin_slug),
        ),
        array(
          'name'     => __('Dropdown', $this->plugin_slug),
          'type'     => 'dropdown',
          'options'  => array('Red', 'Blue'),
          'default'  => false,
          'help'     => __('Select an option from the dropdown.', $this->plugin_slug),
        ),
      ),
    );
  }
  
  /**
   * Initialize the plugin
   *
   * @return void
   */
  public function init()
  {
    add_action('init', array($this, 'loaded'));
  }
    
  /**
   * Plugin loaded
   *
   * @return void
   */
  public function loaded() {
    if (class_exists('PolyPlugins\Settings')) {
      $this->settings = new Settings($this->plugin, $this->namespace, $this->config, $this->fields);
      $this->settings->init();

      add_action('wp_loaded', array($this, 'display_option'));
    } else {
      $this->add_notice('"' . $this->plugin_name . '"' . " requires <a href='/wp-admin/plugin-install.php?tab=plugin-information&amp;plugin=reusable-admin-panel&amp;TB_iframe=true&amp;width=772&amp;height=608' class='thickbox open-plugin-details-modal' aria-label='More information about Reusable Admin Panel' data-title='Reusable Admin Panel'>Reusable Admin Panel</a> to be installed.");
    }
  }
  
  /**
   * Display an option
   *
   * @return void
   */
  public function display_option() {
    $color_picker = $this->settings->get_option('general', 'color-picker');
    $environment  = strtolower($this->settings->get_option('general', 'environment'));
    $api_key      = $this->settings->get_option('general', $environment . '-token');
    ?>
    <script>
      console.log("This is how you get a setting",
        '<?php echo $color_picker; ?>'
      );
      console.log("This is how you get a setting",
        '<?php echo $api_key; ?>'
      );
    </script>
    <?php
  }

  /**
   * Display the notice on the admin backend
   *
   * @return void
   */
  public function display_notice() {
    ?>
    <div class="notice notice-<?php echo $this->admin_notice['type']; ?>">
      <p><?php echo $this->admin_notice['message']; ?></p>
    </div>
    <?php
  }
  
  /**
   * Enqueue the admin notice
   *
   * @param  string $message The message being displayed in admin
   * @param  string $type Optional. The type of message displayed. Default error.
   * @return void
   */
  private function add_notice($message, $type = 'error') {
    $this->admin_notice = array(
      'message' => $message,
      'type'   => $type
    );

    add_action('admin_notices', array($this, 'display_notice'));
  }
}

$test_plugin = new Test_Plugin;
$test_plugin->init();
